package at.xaxa.ledger.ui.category.overview

import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import at.xaxa.ledger.data.EntryRepository
import at.xaxa.ledger.data.db.Category.CategoryEntity
import at.xaxa.ledger.ui.category.add.CategoryListUIState
import at.xaxa.ledger.ui.category.add.CategoryUIState
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.flowOf
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

data class CategoryUIState(val category: CategoryEntity = CategoryEntity(0,"",0))
data class CategoryListUIState(val categories: Flow<List<CategoryEntity>> = flowOf(emptyList()))


class OverviewCategoryViewModel(
    private val savedStateHandle: SavedStateHandle,
    private val repository: EntryRepository
) : ViewModel() {
    var categoryUiState by mutableStateOf(CategoryListUIState())
        private set

    init {
        getAllCategories()
    }

    fun getAllCategories() {
        viewModelScope.launch {
            val categories = withContext(Dispatchers.IO) {
                repository.getAllCategories()
            }
            categoryUiState = CategoryListUIState(categories)

        }
    }
}
