package at.xaxa.ledger.ui.home

import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableFloatStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import at.xaxa.ledger.data.Entry
import at.xaxa.ledger.data.EntryRepository
import at.xaxa.ledger.data.db.BigEntity.BigEntity
import at.xaxa.ledger.ui.category.add.CategoryListUIState
import at.xaxa.ledger.ui.category.edit.CategoryUIState
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.flowOf
import kotlinx.coroutines.flow.forEach
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext


data class EntryListUIState(val entry: Flow<List<BigEntity>> = flowOf(emptyList()))

class HomeViewModel(private val repository: EntryRepository) : ViewModel() {
    var entryUIState by mutableStateOf(EntryListUIState())
    var balance by mutableFloatStateOf(0.0f)
        private set // Restrict external modification

    init {
        viewModelScope.launch {
            val entries = withContext(Dispatchers.IO) {
                repository.getAllBigEntries()
            }
            entryUIState = EntryListUIState(entries)
        }
        //findCategoryByID()

    }

    fun calculateBalance() {
        viewModelScope.launch {
            balance = repository.calculateBalance()
        }
    }
}